@@ -3,10 +3,10 @@
  *  Module    : tcurses.h
  *  Author    : Thomas Dickey
  *  Created   : 1997-03-02
- *  Updated   : 2003-06-27
+ *  Updated   : 2004-07-19
  *  Notes     : curses #include files, #defines & struct's
  *
- * Copyright (c) 1997-2003 Thomas Dickey <dickey@invisible-island.net>
+ * Copyright (c) 1997-2006 Thomas Dickey <dickey@invisible-island.net>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -103,6 +103,7 @@ extern void my_fputc(int ch, FILE *stream);
 extern void my_fputs(const char *str, FILE *stream);
 #		if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 	extern void my_fputwc(wint_t wc, FILE *fp);
+	extern void my_fputws(const wchar_t *wstr, FILE *fp);
 	extern wint_t cmdReadWch(void);
 	extern wint_t ReadWch(void);
 #		endif /* MULTIBYTE_ABLE && !NO_LOCALE */
@@ -124,11 +125,15 @@ extern void write_line(int row, char *buffer);
 
 #		ifdef NEED_TERM_H
 #			include <curses.h>
-#			ifdef HAVE_NCURSES_TERM_H
-#				include <ncurses/term.h>
+#			ifdef HAVE_NCURSESW_TERM_H
+#				include <ncursesw/term.h>
 #			else
-#				include <term.h>
-#			endif /* HAVE_NCURSES_TERM_H */
+#				ifdef HAVE_NCURSES_TERM_H
+#					include <ncurses/term.h>
+#				else
+#					include <term.h>
+#				endif /* HAVE_NCURSES_TERM_H */
+#			endif /* HAVE_NCURSESW_TERM_H */
 #		else
 #			ifdef HAVE_TERMCAP_H
 #				include <termcap.h>
@@ -146,6 +151,12 @@ extern void write_line(int row, char *buffer);
 				else \
 					fputwc(wc, stream); \
 			}
+#			define my_fputws(wstr, stream)	{ \
+				if (fwide(stream, 0) <= 0) \
+					fprintf(stream, "%ls", wstr); \
+				else \
+					fputws(wstr, stream); \
+			}
 #		endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
 #		define my_printf			printf
@@ -153,7 +164,7 @@ extern void write_line(int row, char *buffer);
 #		define my_flush()			fflush(stdout)
 #		define my_fflush(stream)		fflush(stream)
 #		define my_retouch()			ClearScreen()
-#		define WriteLine(row,buffer)		/*nothing*/
+#		define WriteLine(row,buffer)		MoveCursor(row, 0); my_fputs(buffer, stdout);
 
 #		define HpGlitch(func)			if (_hp_glitch) func
 
