@@ -40,10 +40,10 @@
 
 #	define PRODUCT		"tin"
 #	ifndef TIN_AUTOCONF_H
-#		define VERSION		"1.8.2"
+#		define VERSION		"1.8.3"
 #	endif /* !TIN_AUTOCONF_H */
-#	define RELEASEDATE	"20060425"
-#	define RELEASENAME	"Shillay"
+#	define RELEASEDATE	"20070201"
+#	define RELEASENAME	"Scotasay"
 /* config-file versions - must by dotted triples */
 #	define TINRC_VERSION	"1.3.7"
 #	define ATTRIBUTES_VERSION	"1.0.4"
