@@ -3,10 +3,10 @@
  *  Module    : art.c
  *  Author    : I.Lea & R.Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-06-30
+ *  Updated   : 2006-04-21
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -768,7 +768,8 @@ thread_by_percentage(
 		 * we count differences in the length of the strings against
 		 * them matching.
 		 */
-		slen = strlen(arts[base[root_num]].subject);
+		if (!(slen = strlen(arts[base[root_num]].subject)))
+			slen++;
 		unmatched += abs(slen - strlen(arts[i].subject));
 		if ((unmatched * 100) / slen > percentage) {
 			/*
