@@ -6,7 +6,7 @@
  *  Updated   : 1993-03-10
  *  Notes     : Adds default options from environment to command line
  *
- * Copyright (c) 1991-2003 Bill Davidson
+ * Copyright (c) 1991-2006 Bill Davidson
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -125,7 +125,7 @@ envargs(
 	/*
 	 * finally, add a NULL after the last arg, like UNIX
 	 */
-	*argv = (char *) 0;
+	*argv = NULL;
 
 	/*
 	 * save the values and return
