@@ -3,7 +3,7 @@
  *  Module    : filter.c
  *  Author    : I. Lea
  *  Created   : 1992-12-28
- *  Updated   : 2005-07-06
+ *  Updated   : 2006-06-19
  *  Notes     : Filter articles. Kill & auto selection are supported.
  *
  * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>
@@ -1165,8 +1165,9 @@ filter_menu(
 			case FILTER_SUBJ_CASE_SENSITIVE:
 			case FILTER_FROM_CASE_SENSITIVE:
 			case FILTER_MSGID:
-			case FILTER_MSGID_LAST:
-			case FILTER_MSGID_ONLY:
+				rule.counter = FILTER_MSGID_ONLY;
+/*			case FILTER_MSGID_LAST:
+			case FILTER_MSGID_ONLY: */
 				/* rule.icase is FALSE already, no assignment necessary */
 				break;
 
